==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/pl.js <==
/**
 * Polish
 */

$.Editable.LANGS['pl'] = {
  translation: {
    "Bold": "Pogrubienie",
    "Italic": "Kursywa",
    "Underline": "Podkre\u015blenie",
    "Strikethrough": "Przekre\u015blenie",
    "Font Size": "Rozmiar czcionki",
    "Color": "Kolor",
    "Background Color": "Kolor t\u0142a",
    "Text Color": "Kolor tekstu",
    "Format Block": "Formaty",
    "Normal": "Normalny",
    "Paragraph": "Akapit",
    "Code": "Kod \u017ar\u00f3d\u0142owy",
    "Quote": "Cytatu",
    "Heading 1": "Nag\u0142\u00f3wek 1",
    "Heading 2": "Nag\u0142\u00f3wek 2",
    "Heading 3": "Nag\u0142\u00f3wek 3",
    "Heading 4": "Nag\u0142\u00f3wek 4",
    "Heading 5": "Nag\u0142\u00f3wek 5",
    "Heading 6": "Nag\u0142\u00f3wek 6",
    "Alignment": "Wyr\u00f3wnanie",
    "Align Left": "Wyr\u00f3wnaj do lewej",
    "Align Center": "Wyr\u00f3wnaj do \u015brodka",
    "Align Right": "Wyr\u00f3wnaj do prawej",
    "Justify": "Do lewej i prawej",
    "Numbered List": "Lista numerowana",
    "Bulleted List": "Lista wypunktowana",
    "Indent Less": "Zmniejsz wci\u0119cie",
    "Indent More": "Zwi\u0119ksz wci\u0119cie",
    "Select All": "Zaznacz wszystko",
    "Insert Link": "Wstaw link",
    "Insert Image": "Wstaw obrazek",
    "Insert Video": "Wstaw wideo",
    "Undo": "Cofnij",
    "Redo": "Pon\u00f3w",
    "Show HTML": "Poka\u017c HTML",
    "Float Left": "Lewo",
    "Float None": "\u017baden",
    "Float Right": "Prawo",
    "Replace Image": "Wymie\u0144 zdj\u0119cie",
    "Remove Image": "Usu\u0144 zdj\u0119cie",
    "Title": "Tytu\u0142",
    "Insert image": "Wstaw obrazek",
    "Drop image": "Upu\u015bci\u0107 obraz",
    "or click": "lub kliknij",
    "Enter URL": "Wpisz adres URL",
    "Please wait!": "Prosz\u0119 czeka\u0107!",
    "Are you sure? Image will be deleted.": "Czy na pewno? Obraz zostanie skasowany.",
    "UNLINK": "Usu\u0144 link",
    "Open in new tab": "Otw\u00f3rz w nowej karcie",
    "Type something": "Wpisz co\u015b",
    "Cancel": "Anuluj",
    "OK": "Ok",
    "Manage images": "Zarz\u0105dzanie zdj\u0119ciami",
    "Delete": "Usun\u0105\u0107",
    "Font Family": "Kr\u00f3j czcionki",
    "Insert Horizontal Line": "Wstaw lini\u0119 poziom\u0105"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.4.tar.gz: django-froala-editor-0.8.4/froala_editor/static/froala_editor/js/langs/pl.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Polish
 */

$.Editable.LANGS['pl'] = {
  translation: {
    "Bold": "Pogrubienie",
    "Italic": "Kursywa",
    "Underline": "Podkre\u015blenie",
    "Strikethrough": "Przekre\u015blenie",
    "Font Size": "Rozmiar czcionki",
    "Color": "Kolor",
    "Background Color": "Kolor t\u0142a",
    "Text Color": "Kolor tekstu",
    "Format Block": "Formaty",
    "Normal": "Normalny",
    "Paragraph": "Akapit",
    "Code": "Kod \u017ar\u00f3d\u0142owy",
    "Quote": "Cytatu",
    "Heading 1": "Nag\u0142\u00f3wek 1",
    "Heading 2": "Nag\u0142\u00f3wek 2",
    "Heading 3": "Nag\u0142\u00f3wek 3",
    "Heading 4": "Nag\u0142\u00f3wek 4",
    "Heading 5": "Nag\u0142\u00f3wek 5",
    "Heading 6": "Nag\u0142\u00f3wek 6",
    "Alignment": "Wyr\u00f3wnanie",
    "Align Left": "Wyr\u00f3wnaj do lewej",
    "Align Center": "Wyr\u00f3wnaj do \u015brodka",
    "Align Right": "Wyr\u00f3wnaj do prawej",
    "Justify": "Do lewej i prawej",
    "Numbered List": "Lista numerowana",
    "Bulleted List": "Lista wypunktowana",
    "Indent Less": "Zmniejsz wci\u0119cie",
    "Indent More": "Zwi\u0119ksz wci\u0119cie",
    "Select All": "Zaznacz wszystko",
    "Insert Link": "Wstaw link",
    "Insert Image": "Wstaw obrazek",
    "Insert Video": "Wstaw wideo",
    "Undo": "Cofnij",
    "Redo": "Pon\u00f3w",
    "Show HTML": "Poka\u017c HTML",
    "Float Left": "Lewo",
    "Float None": "\u017baden",
    "Float Right": "Prawo",
    "Replace Image": "Wymie\u0144 zdj\u0119cie",
    "Remove Image": "Usu\u0144 zdj\u0119cie",
    "Title": "Tytu\u0142",
    "Insert image": "Wstaw obrazek",
    "Drop image": "Upu\u015bci\u0107 obraz",
    "or click": "lub kliknij",
    "Enter URL": "Wpisz adres URL",
    "Please wait!": "Prosz\u0119 czeka\u0107!",
    "Are you sure? Image will be deleted.": "Czy na pewno? Obraz zostanie skasowany.",
    "UNLINK": "Usu\u0144 link",
    "Open in new tab": "Otw\u00f3rz w nowej karcie",
    "Type something": "Wpisz co\u015b",
    "Cancel": "Anuluj",
    "OK": "Ok",
    "Manage images": "Zarz\u0105dzanie zdj\u0119ciami",
    "Delete": "Usun\u0105\u0107",
    "Font Family": "Kr\u00f3j czcionki",
    "Insert Horizontal Line": "Wstaw lini\u0119 poziom\u0105",
    "Table": "Tabela",
    "Insert table": "Wstaw tabel\u0119",
    "Cell": "Kom\u00f3rka",
    "Row": "Wiersz",
    "Column": "Kolumna",
    "Delete table": "Usu\u0144 tabel\u0119",
    "Insert cell before": "Wstaw kom\u00f3rk\u0119 przed",
    "Insert cell after": "Wstaw kom\u00f3rk\u0119 po",
    "Delete cell": "Usu\u0144 kom\u00f3rk\u0119",
    "Merge cells": "\u0141\u0105cz kom\u00f3rki",
    "Horizontal split": "Podzia\u0142 poziomy",
    "Vertical split": "Podzia\u0142 pionowy",
    "Insert row above": "Wstaw wiersz przed",
    "Insert row below": "Wstaw wiersz po",
    "Delete row": "Usu\u0144 wiersz",
    "Insert column before": "Wstaw kolumn\u0119 przed",
    "Insert column after": "Wstaw kolumn\u0119 po",
    "Delete column": "Usu\u0144 kolumn\u0119"
  },
  direction: "ltr"
};
